summaryrefslogtreecommitdiffstats
path: root/src/plugin.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/plugin.c')
-rw-r--r--src/plugin.c78
1 files changed, 39 insertions, 39 deletions
diff --git a/src/plugin.c b/src/plugin.c
index 1c95225..1216535 100644
--- a/src/plugin.c
+++ b/src/plugin.c
@@ -1,20 +1,20 @@
/* $Id$ */
/***
- This file is part of xmms-polyp.
+ This file is part of xmms-pulse.
- xmms-polyp is free software; you can redistribute it and/or modify
+ xmms-pulse is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
- xmms-polyp is distributed in the hope that it will be useful, but
+ xmms-pulse is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
General Public License for more details.
You should have received a copy of the GNU General Public License
- along with xmms-polyp; if not, write to the Free Software
+ along with xmms-pulse; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
USA.
***/
@@ -32,7 +32,7 @@
#include <xmmsctrl.h>
#include <util.h>
-#include <polyp/polypaudio.h>
+#include <pulse/pulseaudio.h>
static pa_context *context = NULL;
static pa_stream *stream = NULL;
@@ -178,7 +178,7 @@ static void stream_latency_update_cb(pa_stream *s, void *userdata) {
pa_threaded_mainloop_signal(mainloop, 0);
}
-static void polyp_get_volume(int *l, int *r) {
+static void pulse_get_volume(int *l, int *r) {
pa_cvolume v;
int b = 0;
@@ -223,7 +223,7 @@ static void volume_time_cb(pa_mainloop_api *api, pa_time_event *e, const struct
volume_time_event = NULL;
}
-static void polyp_set_volume(int l, int r) {
+static void pulse_set_volume(int l, int r) {
/* g_message("set_volume"); */
@@ -254,7 +254,7 @@ fail:
pa_threaded_mainloop_unlock(mainloop);
}
-static void polyp_pause(short b) {
+static void pulse_pause(short b) {
pa_operation *o = NULL;
int success = 0;
@@ -286,7 +286,7 @@ fail:
pa_threaded_mainloop_unlock(mainloop);
}
-static int polyp_free(void) {
+static int pulse_free(void) {
size_t l = 0;
pa_operation *o = NULL;
@@ -303,7 +303,7 @@ static int polyp_free(void) {
goto fail;
}
/* If this function is called twice with no polyp_write() call in
* between this means we should trigger the playback */
if (do_trigger) {
int success = 0;
@@ -329,7 +329,7 @@ fail:
return (int) l;
}
-static int polyp_get_written_time(void) {
+static int pulse_get_written_time(void) {
int r = 0;
/* g_message("get_written_time"); */
@@ -349,7 +349,7 @@ fail:
return r;
}
-static int polyp_get_output_time(void) {
+static int pulse_get_output_time(void) {
int r = 0;
pa_usec_t t;
@@ -390,7 +390,7 @@ fail:
return r;
}
-static int polyp_playing(void) {
+static int pulse_playing(void) {
int r = 0;
const pa_timing_info *i;
@@ -422,7 +422,7 @@ fail:
return r;
}
-static void polyp_flush(int time) {
+static void pulse_flush(int time) {
pa_operation *o = NULL;
int success = 0;
@@ -457,7 +457,7 @@ fail:
pa_threaded_mainloop_unlock(mainloop);
}
-static void polyp_write(void* ptr, int length) {
+static void pulse_write(void* ptr, int length) {
/* g_message("write"); */
@@ -508,7 +508,7 @@ fail:
pa_threaded_mainloop_unlock(mainloop);
}
-static void polyp_close(void) {
+static void pulse_close(void) {
/* g_message("close"); */
@@ -539,7 +539,7 @@ static void polyp_close(void) {
volume_time_event = NULL;
}
-static int polyp_open(AFormat fmt, int rate, int nch) {
+static int pulse_open(AFormat fmt, int rate, int nch) {
pa_sample_spec ss;
pa_operation *o = NULL;
int success;
@@ -684,23 +684,23 @@ unlock_and_fail:
fail:
- polyp_close();
+ pulse_close();
return FALSE;
}
-static void polyp_init(void) {
+static void pulse_init(void) {
}
-static void polyp_about(void) {
+static void pulse_about(void) {
static GtkWidget *dialog;
if (dialog != NULL)
return;
dialog = xmms_show_message(
- "About XMMS Polypaudio Output Plugin",
- "XMMS Polypaudio Output Plugin\n\n "
+ "About XMMS PulseAudio Output Plugin",
+ "XMMS PulseAudio Output Plugin\n\n "
"This program is free software; you can redistribute it and/or modify\n"
"it under the terms of the GNU General Public License as published by\n"
"the Free Software Foundation; either version 2 of the License, or\n"
@@ -729,25 +729,25 @@ static void polyp_about(void) {
OutputPlugin *get_oplugin_info(void) {
- static OutputPlugin polyp_plugin = {
+ static OutputPlugin pulse_plugin = {
NULL,
NULL,
- "Polypaudio Output Plugin",
- polyp_init,
- polyp_about,
- NULL, /* polyp_configure, */
- polyp_get_volume,
- polyp_set_volume,
- polyp_open,
- polyp_write,
- polyp_close,
- polyp_flush,
- polyp_pause,
- polyp_free,
- polyp_playing,
- polyp_get_output_time,
- polyp_get_written_time,
+ "PulseAudio Output Plugin",
+ pulse_init,
+ pulse_about,
+ NULL, /* pulse_configure, */
+ pulse_get_volume,
+ pulse_set_volume,
+ pulse_open,
+ pulse_write,
+ pulse_close,
+ pulse_flush,
+ pulse_pause,
+ pulse_free,
+ pulse_playing,
+ pulse_get_output_time,
+ pulse_get_written_time,
};
- return &polyp_plugin;
+ return &pulse_plugin;
}
@@ -303,7 +303,7 @@ static int polyp_free(void) {
goto fail;
}
- /* If this function is called twice with no polyp_write() call in
+ /* If this function is called twice with no pulse_write() call in
* between this means we should trigger the playback */
if (do_trigger) {